==> cc_clients_python_lib-0.28.6.0.tar.gz: cc_clients_python_lib-0.28.6.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is base on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.28.06.000] - 2025-09-29
### Added
- Issue [#318](https://github.com/j3-signalroom/cc-clients-lib/issues/318)

## [0.28.05.000] - 2025-09-29
### Fixed
- Issue [#315](https://github.com/j3-signalroom/cc-clients-lib/issues/315)

## [0.28.04.000] - 2025-09-27
### Changed
- Issue [#313](https://github.com/j3-signalroom/cc-clients-lib/issues/313)

## [0.28.03.000] - 2025-09-27
### Changed
- Issue [#311](https://github.com/j3-signalroom/cc-clients-lib/issues/311)

## [0.28.02.000] - 2025-09-27
### Changed
- Issue [#309](https://github.com/j3-signalroom/cc-clients-lib/issues/309)

## [0.28.01.000] - 2025-09-27
### Changed
- Issue [#307](https://github.com/j3-signalroom/cc-clients-lib/issues/307)

## [0.28.00.000] - 2025-09-26
### Added
- Issue [#297](https://github.com/j3-signalroom/cc-clients-lib/issues/297)
- Issue [#299](https://github.com/j3-signalroom/cc-clients-lib/issues/299)
- Issue [#305](https://github.com/j3-signalroom/cc-clients-lib/issues/305)

### Changed
- Issue [#301](https://github.com/j3-signalroom/cc-clients-lib/issues/301)
- Issue [#303](https://github.com/j3-signalroom/cc-clients-lib/issues/303)

## [0.27.00.000] - 2025-09-24
### Added
- Issue [#295](https://github.com/j3-signalroom/cc-clients-lib/issues/295)

## [0.26.00.000] - 2025-09-24
### Added
- Issue [#291](https://github.com/j3-signalroom/cc-clients-lib/issues/291)
- Issue [#293](https://github.com/j3-signalroom/cc-clients-lib/issues/293)

## [0.25.00.000] - 2025-09-20
### Added
- Issue [#286](https://github.com/j3-signalroom/cc-clients-lib/issues/286)
- Issue [#289](https://github.com/j3-signalroom/cc-clients-lib/issues/289)

## [0.24.00.000] - 2025-09-19
### Added
- Issue [#283](https://github.com/j3-signalroom/cc-clients-lib/issues/283)

## [0.23.00.000] - 2025-09-14
### Added
- Issue [#280](https://github.com/j3-signalroom/cc-clients-lib/issues/280)

## [0.22.00.000] - 2025-09-14
### Added
- Issue [#278](https://github.com/j3-signalroom/cc-clients-lib/issues/278)

## [0.22.00.000] - 2025-09-14
### Added
- Issue [#278](https://github.com/j3-signalroom/cc-clients-lib/issues/278)

### Changed
- Issue [#276](https://github.com/j3-signalroom/cc-clients-lib/issues/276)

## [0.21.00.000] - 2025-09-13
### Changed
- Issue [#274](https://github.com/j3-signalroom/cc-clients-lib/issues/274)

## [0.20.00.000] - 2025-09-13
### Added
- Issue [#268](https://github.com/j3-signalroom/cc-clients-lib/issues/268)

### Changed
- Issue [#266](https://github.com/j3-signalroom/cc-clients-lib/issues/266)

### Fixed
- Issue [#270](https://github.com/j3-signalroom/cc-clients-lib/issues/270)

## [0.19.00.000] - 2025-05-23
### Added
- Issue [#255](https://github.com/j3-signalroom/cc-clients-lib/issues/255)
- Issue [#257](https://github.com/j3-signalroom/cc-clients-lib/issues/257)
- Issue [#261](https://github.com/j3-signalroom/cc-clients-lib/issues/261)
- Issue [#263](https://github.com/j3-signalroom/cc-clients-lib/issues/263)

### Changed
- Issue [#259](https://github.com/j3-signalroom/cc-clients-lib/issues/259)

## [0.18.02.000] - 2025-05-11
### Added
- Issue [#252](https://github.com/j3-signalroom/cc-clients-lib/issues/252)

## [0.18.01.000] - 2025-05-11
### Added
- Issue [#252](https://github.com/j3-signalroom/cc-clients-lib/issues/252)

## [0.18.00.000] - 2025-05-10
### Added
- Issue [#250](https://github.com/j3-signalroom/cc-clients-lib/issues/250)

## [0.17.00.000] - 2025-05-10
### Added
- Issue [#233](https://github.com/j3-signalroom/cc-clients-lib/issues/233)
- Issue [#234](https://github.com/j3-signalroom/cc-clients-lib/issues/234)
- Issue [#237](https://github.com/j3-signalroom/cc-clients-lib/issues/237)
- Issue [#245](https://github.com/j3-signalroom/cc-clients-lib/issues/245)

### Changed
- Issue [#235](https://github.com/j3-signalroom/cc-clients-lib/issues/235)

### Fixed
- Issue [#247](https://github.com/j3-signalroom/cc-clients-lib/issues/247)

## [0.16.05.000] - 2025-05-05
### Changed
- Issue [#223](https://github.com/j3-signalroom/cc-clients-lib/issues/223)
- Issue [#224](https://github.com/j3-signalroom/cc-clients-lib/issues/224)
- Issue [#225](https://github.com/j3-signalroom/cc-clients-lib/issues/225)

## [0.16.04.000] - 2025-05-04
### Changed
- Issue [#219](https://github.com/j3-signalroom/cc-clients-lib/issues/219)

### Fixed
- Issue [#217](https://github.com/j3-signalroom/cc-clients-lib/issues/217)

## [0.16.03.000] - 2025-05-04
### Changed
- Issue [#215](https://github.com/j3-signalroom/cc-clients-lib/issues/215)

## [0.16.02.000] - 2025-05-03
### Changed
- Issue [#210](https://github.com/j3-signalroom/cc-clients-lib/issues/210)

## [0.16.01.000] - 2025-05-03
### Changed
- Issue [#208](https://github.com/j3-signalroom/cc-clients-lib/issues/208)

## [0.16.00.000] - 2025-05-03
### Added
- Issue [#191](https://github.com/j3-signalroom/cc-clients-lib/issues/191)
- Issue [#192](https://github.com/j3-signalroom/cc-clients-lib/issues/192)
- Issue [#204](https://github.com/j3-signalroom/cc-clients-lib/issues/204)

## [0.15.00.000] - 2025-04-28
### Added
- Issue [#184](https://github.com/j3-signalroom/cc-clients-lib/issues/184)
- Issue [#185](https://github.com/j3-signalroom/cc-clients-lib/issues/185)

## [0.14.00.000] - 2025-04-27
### Added
- Issue [#156](https://github.com/j3-signalroom/cc-clients-lib/issues/156)
- Issue [#157](https://github.com/j3-signalroom/cc-clients-lib/issues/157)
- Issue [#168](https://github.com/j3-signalroom/cc-clients-lib/issues/168)

### Fixed
- Issue [#160](https://github.com/j3-signalroom/cc-clients-lib/issues/160)
- Issue [#164](https://github.com/j3-signalroom/cc-clients-lib/issues/164)
- Issue [#166](https://github.com/j3-signalroom/cc-clients-lib/issues/166)

## [0.13.01.000] - 2025-03-26
### Changed
- Issue [#154](https://github.com/j3-signalroom/cc-clients-lib/issues/154)

## [0.13.00.000] - 2025-03-22
### Added
- Issue [#146](https://github.com/j3-signalroom/cc-clients-lib/issues/146)
- Issue [#147](https://github.com/j3-signalroom/cc-clients-lib/issues/147)

### Changed
- Issue [#151](https://github.com/j3-signalroom/cc-clients-lib/issues/151)

## [0.12.03.000] - 2025-03-05
### Changed
- Issue [#142](https://github.com/j3-signalroom/cc-clients-lib/issues/142)

## [0.12.02.000] - 2025-03-05
### Changed
- Issue [#135](https://github.com/j3-signalroom/cc-clients-lib/issues/135)
- Issue [#136](https://github.com/j3-signalroom/cc-clients-lib/issues/136)

## [0.12.01.000] - 2025-03-05
### Added
- Issue [#71](https://github.com/j3-signalroom/cc-clients-lib/issues/71)
- Issue [#99](https://github.com/j3-signalroom/cc-clients-lib/issues/99)

### Changed
- Issue [#127](https://github.com/j3-signalroom/cc-clients-lib/issues/127)

## [0.12.00.000] - 2025-03-05
### Added
- Issue [#123](https://github.com/j3-signalroom/cc-clients-lib/issues/123)

## [0.11.01.000] - 2025-03-04
### Changed
- Issue [#121](https://github.com/j3-signalroom/cc-clients-lib/issues/121)

## [0.11.00.000] - 2025-03-03
### Added
- Issue [#118](https://github.com/j3-signalroom/cc-clients-lib/issues/118)

## [0.10.03.000] - 2025-03-03
### Fixed
- Issue [#116](https://github.com/j3-signalroom/cc-clients-lib/issues/116)

## [0.10.02.000] - 2025-03-03
### Changed
- Issue [#114](https://github.com/j3-signalroom/cc-clients-lib/issues/114)

## [0.10.01.000] - 2025-03-03
### Changed
- Issue [#112](https://github.com/j3-signalroom/cc-clients-lib/issues/112)

## [0.10.00.000] - 2025-03-03
### Added
- Issue [#108](https://github.com/j3-signalroom/cc-clients-lib/issues/108)

## [0.09.00.000] - 2025-03-02
### Added
- Issue [#104](https://github.com/j3-signalroom/cc-clients-lib/issues/104)

## [0.08.03.000] - 2025-03-02
### Added
- Issue [#100](https://github.com/j3-signalroom/cc-clients-lib/issues/100)

## [0.08.02.000] - 2025-03-01
### Changed
- Issue [#97](https://github.com/j3-signalroom/cc-clients-lib/issues/97)

## [0.08.01.000] - 2025-03-01
### Changed
- Issue [#94](https://github.com/j3-signalroom/cc-clients-lib/issues/94)

## [0.08.00.000] - 2025-03-01
### Added
- Issue [#89](https://github.com/j3-signalroom/cc-clients-lib/issues/89)
- Issue [#90](https://github.com/j3-signalroom/cc-clients-lib/issues/90)

## [0.07.01.000] - 2025-03-01
### Changed
- Issue [#87](https://github.com/j3-signalroom/cc-clients-lib/issues/87)

## [0.07.00.000] - 2025-02-28
### Added
- Issue [#81](https://github.com/j3-signalroom/cc-clients-lib/issues/81)
- Issue [#82](https://github.com/j3-signalroom/cc-clients-lib/issues/82)

## [0.06.00.000] - 2025-02-26
### Added
- Issue [#78](https://github.com/j3-signalroom/cc-clients-lib/issues/78)

## [0.05.00.000] - 2025-02-26
### Added
- Issue [#72](https://github.com/j3-signalroom/cc-clients-lib/issues/72)

## [0.04.00.000] - 2025-02-24
### Added
- Issue [#51](https://github.com/j3-signalroom/cc-clients-lib/issues/51)
- Issue [#53](https://github.com/j3-signalroom/cc-clients-lib/issues/53)
- Issue [#54](https://github.com/j3-signalroom/cc-clients-lib/issues/54)
- Issue [#55](https://github.com/j3-signalroom/cc-clients-lib/issues/55)
- Issue [#56](https://github.com/j3-signalroom/cc-clients-lib/issues/56)
- Issue [#57](https://github.com/j3-signalroom/cc-clients-lib/issues/57)
- Issue [#58](https://github.com/j3-signalroom/cc-clients-lib/issues/58)

## [0.03.00.000] - 2025-02-23
### Added
- Issue [#30](https://github.com/j3-signalroom/cc-clients-lib/issues/30)
- Issue [#32](https://github.com/j3-signalroom/cc-clients-lib/issues/32)
- Issue [#33](https://github.com/j3-signalroom/cc-clients-lib/issues/33)

### Changed
- Issue [#28](https://github.com/j3-signalroom/cc-clients-lib/issues/28)
- Issue [#34](https://github.com/j3-signalroom/cc-clients-lib/issues/34)
- Issue [#35](https://github.com/j3-signalroom/cc-clients-lib/issues/35)
- Issue [#40](https://github.com/j3-signalroom/cc-clients-lib/issues/40)
- Issue [#43](https://github.com/j3-signalroom/cc-clients-lib/issues/43)

## [0.02.00.000] - 2025-02-22
### Added
- Added support for Confluent Cloud for Apache Flink (CCAF).

## [0.01.00.000] - 2025-02-22
### Added
- First release.

==> cc_clients_python_lib-0.28.8.0.tar.gz: cc_clients_python_lib-0.28.8.0/CHANGELOG.md <==
# Changelog
All notable changes to this project will be documented in this file.

The format is base on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/), and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.28.08.000] - 2025-09-30
### Added
- Issue [#320](https://github.com/j3-signalroom/cc-clients-lib/issues/320)

## [0.28.07.000] - 2025-09-29
### Added
- Issue [#320](https://github.com/j3-signalroom/cc-clients-lib/issues/320)

## [0.28.06.000] - 2025-09-29
### Added
- Issue [#318](https://github.com/j3-signalroom/cc-clients-lib/issues/318)

## [0.28.05.000] - 2025-09-29
### Fixed
- Issue [#315](https://github.com/j3-signalroom/cc-clients-lib/issues/315)

## [0.28.04.000] - 2025-09-27
### Changed
- Issue [#313](https://github.com/j3-signalroom/cc-clients-lib/issues/313)

## [0.28.03.000] - 2025-09-27
### Changed
- Issue [#311](https://github.com/j3-signalroom/cc-clients-lib/issues/311)

## [0.28.02.000] - 2025-09-27
### Changed
- Issue [#309](https://github.com/j3-signalroom/cc-clients-lib/issues/309)

## [0.28.01.000] - 2025-09-27
### Changed
- Issue [#307](https://github.com/j3-signalroom/cc-clients-lib/issues/307)

## [0.28.00.000] - 2025-09-26
### Added
- Issue [#297](https://github.com/j3-signalroom/cc-clients-lib/issues/297)
- Issue [#299](https://github.com/j3-signalroom/cc-clients-lib/issues/299)
- Issue [#305](https://github.com/j3-signalroom/cc-clients-lib/issues/305)

### Changed
- Issue [#301](https://github.com/j3-signalroom/cc-clients-lib/issues/301)
- Issue [#303](https://github.com/j3-signalroom/cc-clients-lib/issues/303)

## [0.27.00.000] - 2025-09-24
### Added
- Issue [#295](https://github.com/j3-signalroom/cc-clients-lib/issues/295)

## [0.26.00.000] - 2025-09-24
### Added
- Issue [#291](https://github.com/j3-signalroom/cc-clients-lib/issues/291)
- Issue [#293](https://github.com/j3-signalroom/cc-clients-lib/issues/293)

## [0.25.00.000] - 2025-09-20
### Added
- Issue [#286](https://github.com/j3-signalroom/cc-clients-lib/issues/286)
- Issue [#289](https://github.com/j3-signalroom/cc-clients-lib/issues/289)

## [0.24.00.000] - 2025-09-19
### Added
- Issue [#283](https://github.com/j3-signalroom/cc-clients-lib/issues/283)

## [0.23.00.000] - 2025-09-14
### Added
- Issue [#280](https://github.com/j3-signalroom/cc-clients-lib/issues/280)

## [0.22.00.000] - 2025-09-14
### Added
- Issue [#278](https://github.com/j3-signalroom/cc-clients-lib/issues/278)

## [0.22.00.000] - 2025-09-14
### Added
- Issue [#278](https://github.com/j3-signalroom/cc-clients-lib/issues/278)

### Changed
- Issue [#276](https://github.com/j3-signalroom/cc-clients-lib/issues/276)

## [0.21.00.000] - 2025-09-13
### Changed
- Issue [#274](https://github.com/j3-signalroom/cc-clients-lib/issues/274)

## [0.20.00.000] - 2025-09-13
### Added
- Issue [#268](https://github.com/j3-signalroom/cc-clients-lib/issues/268)

### Changed
- Issue [#266](https://github.com/j3-signalroom/cc-clients-lib/issues/266)

### Fixed
- Issue [#270](https://github.com/j3-signalroom/cc-clients-lib/issues/270)

## [0.19.00.000] - 2025-05-23
### Added
- Issue [#255](https://github.com/j3-signalroom/cc-clients-lib/issues/255)
- Issue [#257](https://github.com/j3-signalroom/cc-clients-lib/issues/257)
- Issue [#261](https://github.com/j3-signalroom/cc-clients-lib/issues/261)
- Issue [#263](https://github.com/j3-signalroom/cc-clients-lib/issues/263)

### Changed
- Issue [#259](https://github.com/j3-signalroom/cc-clients-lib/issues/259)

## [0.18.02.000] - 2025-05-11
### Added
- Issue [#252](https://github.com/j3-signalroom/cc-clients-lib/issues/252)

## [0.18.01.000] - 2025-05-11
### Added
- Issue [#252](https://github.com/j3-signalroom/cc-clients-lib/issues/252)

## [0.18.00.000] - 2025-05-10
### Added
- Issue [#250](https://github.com/j3-signalroom/cc-clients-lib/issues/250)

## [0.17.00.000] - 2025-05-10
### Added
- Issue [#233](https://github.com/j3-signalroom/cc-clients-lib/issues/233)
- Issue [#234](https://github.com/j3-signalroom/cc-clients-lib/issues/234)
- Issue [#237](https://github.com/j3-signalroom/cc-clients-lib/issues/237)
- Issue [#245](https://github.com/j3-signalroom/cc-clients-lib/issues/245)

### Changed
- Issue [#235](https://github.com/j3-signalroom/cc-clients-lib/issues/235)

### Fixed
- Issue [#247](https://github.com/j3-signalroom/cc-clients-lib/issues/247)

## [0.16.05.000] - 2025-05-05
### Changed
- Issue [#223](https://github.com/j3-signalroom/cc-clients-lib/issues/223)
- Issue [#224](https://github.com/j3-signalroom/cc-clients-lib/issues/224)
- Issue [#225](https://github.com/j3-signalroom/cc-clients-lib/issues/225)

## [0.16.04.000] - 2025-05-04
### Changed
- Issue [#219](https://github.com/j3-signalroom/cc-clients-lib/issues/219)

### Fixed
- Issue [#217](https://github.com/j3-signalroom/cc-clients-lib/issues/217)

## [0.16.03.000] - 2025-05-04
### Changed
- Issue [#215](https://github.com/j3-signalroom/cc-clients-lib/issues/215)

## [0.16.02.000] - 2025-05-03
### Changed
- Issue [#210](https://github.com/j3-signalroom/cc-clients-lib/issues/210)

## [0.16.01.000] - 2025-05-03
### Changed
- Issue [#208](https://github.com/j3-signalroom/cc-clients-lib/issues/208)

## [0.16.00.000] - 2025-05-03
### Added
- Issue [#191](https://github.com/j3-signalroom/cc-clients-lib/issues/191)
- Issue [#192](https://github.com/j3-signalroom/cc-clients-lib/issues/192)
- Issue [#204](https://github.com/j3-signalroom/cc-clients-lib/issues/204)

## [0.15.00.000] - 2025-04-28
### Added
- Issue [#184](https://github.com/j3-signalroom/cc-clients-lib/issues/184)
- Issue [#185](https://github.com/j3-signalroom/cc-clients-lib/issues/185)

## [0.14.00.000] - 2025-04-27
### Added
- Issue [#156](https://github.com/j3-signalroom/cc-clients-lib/issues/156)
- Issue [#157](https://github.com/j3-signalroom/cc-clients-lib/issues/157)
- Issue [#168](https://github.com/j3-signalroom/cc-clients-lib/issues/168)

### Fixed
- Issue [#160](https://github.com/j3-signalroom/cc-clients-lib/issues/160)
- Issue [#164](https://github.com/j3-signalroom/cc-clients-lib/issues/164)
- Issue [#166](https://github.com/j3-signalroom/cc-clients-lib/issues/166)

## [0.13.01.000] - 2025-03-26
### Changed
- Issue [#154](https://github.com/j3-signalroom/cc-clients-lib/issues/154)

## [0.13.00.000] - 2025-03-22
### Added
- Issue [#146](https://github.com/j3-signalroom/cc-clients-lib/issues/146)
- Issue [#147](https://github.com/j3-signalroom/cc-clients-lib/issues/147)

### Changed
- Issue [#151](https://github.com/j3-signalroom/cc-clients-lib/issues/151)

## [0.12.03.000] - 2025-03-05
### Changed
- Issue [#142](https://github.com/j3-signalroom/cc-clients-lib/issues/142)

## [0.12.02.000] - 2025-03-05
### Changed
- Issue [#135](https://github.com/j3-signalroom/cc-clients-lib/issues/135)
- Issue [#136](https://github.com/j3-signalroom/cc-clients-lib/issues/136)

## [0.12.01.000] - 2025-03-05
### Added
- Issue [#71](https://github.com/j3-signalroom/cc-clients-lib/issues/71)
- Issue [#99](https://github.com/j3-signalroom/cc-clients-lib/issues/99)

### Changed
- Issue [#127](https://github.com/j3-signalroom/cc-clients-lib/issues/127)

## [0.12.00.000] - 2025-03-05
### Added
- Issue [#123](https://github.com/j3-signalroom/cc-clients-lib/issues/123)

## [0.11.01.000] - 2025-03-04
### Changed
- Issue [#121](https://github.com/j3-signalroom/cc-clients-lib/issues/121)

## [0.11.00.000] - 2025-03-03
### Added
- Issue [#118](https://github.com/j3-signalroom/cc-clients-lib/issues/118)

## [0.10.03.000] - 2025-03-03
### Fixed
- Issue [#116](https://github.com/j3-signalroom/cc-clients-lib/issues/116)

## [0.10.02.000] - 2025-03-03
### Changed
- Issue [#114](https://github.com/j3-signalroom/cc-clients-lib/issues/114)

## [0.10.01.000] - 2025-03-03
### Changed
- Issue [#112](https://github.com/j3-signalroom/cc-clients-lib/issues/112)

## [0.10.00.000] - 2025-03-03
### Added
- Issue [#108](https://github.com/j3-signalroom/cc-clients-lib/issues/108)

## [0.09.00.000] - 2025-03-02
### Added
- Issue [#104](https://github.com/j3-signalroom/cc-clients-lib/issues/104)

## [0.08.03.000] - 2025-03-02
### Added
- Issue [#100](https://github.com/j3-signalroom/cc-clients-lib/issues/100)

## [0.08.02.000] - 2025-03-01
### Changed
- Issue [#97](https://github.com/j3-signalroom/cc-clients-lib/issues/97)

## [0.08.01.000] - 2025-03-01
### Changed
- Issue [#94](https://github.com/j3-signalroom/cc-clients-lib/issues/94)

## [0.08.00.000] - 2025-03-01
### Added
- Issue [#89](https://github.com/j3-signalroom/cc-clients-lib/issues/89)
- Issue [#90](https://github.com/j3-signalroom/cc-clients-lib/issues/90)

## [0.07.01.000] - 2025-03-01
### Changed
- Issue [#87](https://github.com/j3-signalroom/cc-clients-lib/issues/87)

## [0.07.00.000] - 2025-02-28
### Added
- Issue [#81](https://github.com/j3-signalroom/cc-clients-lib/issues/81)
- Issue [#82](https://github.com/j3-signalroom/cc-clients-lib/issues/82)

## [0.06.00.000] - 2025-02-26
### Added
- Issue [#78](https://github.com/j3-signalroom/cc-clients-lib/issues/78)

## [0.05.00.000] - 2025-02-26
### Added
- Issue [#72](https://github.com/j3-signalroom/cc-clients-lib/issues/72)

## [0.04.00.000] - 2025-02-24
### Added
- Issue [#51](https://github.com/j3-signalroom/cc-clients-lib/issues/51)
- Issue [#53](https://github.com/j3-signalroom/cc-clients-lib/issues/53)
- Issue [#54](https://github.com/j3-signalroom/cc-clients-lib/issues/54)
- Issue [#55](https://github.com/j3-signalroom/cc-clients-lib/issues/55)
- Issue [#56](https://github.com/j3-signalroom/cc-clients-lib/issues/56)
- Issue [#57](https://github.com/j3-signalroom/cc-clients-lib/issues/57)
- Issue [#58](https://github.com/j3-signalroom/cc-clients-lib/issues/58)

## [0.03.00.000] - 2025-02-23
### Added
- Issue [#30](https://github.com/j3-signalroom/cc-clients-lib/issues/30)
- Issue [#32](https://github.com/j3-signalroom/cc-clients-lib/issues/32)
- Issue [#33](https://github.com/j3-signalroom/cc-clients-lib/issues/33)

### Changed
- Issue [#28](https://github.com/j3-signalroom/cc-clients-lib/issues/28)
- Issue [#34](https://github.com/j3-signalroom/cc-clients-lib/issues/34)
- Issue [#35](https://github.com/j3-signalroom/cc-clients-lib/issues/35)
- Issue [#40](https://github.com/j3-signalroom/cc-clients-lib/issues/40)
- Issue [#43](https://github.com/j3-signalroom/cc-clients-lib/issues/43)

## [0.02.00.000] - 2025-02-22
### Added
- Added support for Confluent Cloud for Apache Flink (CCAF).

## [0.01.00.000] - 2025-02-22
### Added
- First release.
